==> haskell-mutable-containers-0.3.4.1-176-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-AzR6TdGWcCI7uVy0Ip8yml
key:                  mutable-containers-0.3.4.1-AzR6TdGWcCI7uVy0Ip8yml
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  ee6df5d90f2f41cd2ff393f5ead4f768
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-AzR6TdGWcCI7uVy0Ip8yml
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    mono-traversable-1.0.21.0-5COWhUczLvWDWjS7xXP2hN
    primitive-0.9.1.0-3L6fSIJx0fWJUtVHVLpgAb
    vector-0.13.2.0-BWMo7dqC00725tIPRLs4rJ

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mutable-containers-0.3.4.1-177-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-DufBCioXazF3NVFbVm9WgR
key:                  mutable-containers-0.3.4.1-DufBCioXazF3NVFbVm9WgR
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  ef1dc046598af20950540dac51e8e34b
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-DufBCioXazF3NVFbVm9WgR
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    mono-traversable-1.0.21.0-KjEdkWGeLSA4Md2at95UKe
    primitive-0.9.1.0-3L6fSIJx0fWJUtVHVLpgAb
    vector-0.13.2.0-3KdUWUHYfVjDmpelwHDbn6

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
